@@ -4,16 +4,14 @@ Main interface for comprehendmedical service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_comprehendmedical import (
         Client,
         ComprehendMedicalClient,
     )
 
-    session = boto3.Session()
-
-    client: ComprehendMedicalClient = boto3.client("comprehendmedical")
-    session_client: ComprehendMedicalClient = session.client("comprehendmedical")
+    session = Session()
+    client: ComprehendMedicalClient = session.client("comprehendmedical")
     ```
 """
 from .client import ComprehendMedicalClient
