@@ -40,7 +40,9 @@ __all__ = (
     "SNOMEDCTEntityTypeType",
     "SNOMEDCTRelationshipTypeType",
     "SNOMEDCTTraitNameType",
+    "ComprehendMedicalServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -152,6 +154,7 @@ SNOMEDCTRelationshipTypeType = Literal[
     "ACUITY", "DIRECTION", "QUALITY", "SYSTEM_ORGAN_SITE", "TEST_UNITS", "TEST_VALUE"
 ]
 SNOMEDCTTraitNameType = Literal["DIAGNOSIS", "NEGATION", "SIGN", "SYMPTOM"]
+ComprehendMedicalServiceName = Literal["comprehendmedical"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -183,6 +186,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -305,6 +309,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -453,3 +458,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
