@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AttributeNameType,
     EntitySubTypeType,
@@ -125,58 +127,54 @@ __all__ = (
 AttributeTypeDef = TypedDict(
     "AttributeTypeDef",
     {
-        "Type": EntitySubTypeType,
-        "Score": float,
-        "RelationshipScore": float,
-        "RelationshipType": RelationshipTypeType,
-        "Id": int,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Text": str,
-        "Category": EntityTypeType,
-        "Traits": List["TraitTypeDef"],
+        "Type": NotRequired[EntitySubTypeType],
+        "Score": NotRequired[float],
+        "RelationshipScore": NotRequired[float],
+        "RelationshipType": NotRequired[RelationshipTypeType],
+        "Id": NotRequired[int],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Text": NotRequired[str],
+        "Category": NotRequired[EntityTypeType],
+        "Traits": NotRequired[List["TraitTypeDef"]],
     },
-    total=False,
 )
 
 CharactersTypeDef = TypedDict(
     "CharactersTypeDef",
     {
-        "OriginalTextCharacters": int,
+        "OriginalTextCharacters": NotRequired[int],
     },
-    total=False,
 )
 
 ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
     "ComprehendMedicalAsyncJobFilterTypeDef",
     {
-        "JobName": str,
-        "JobStatus": JobStatusType,
-        "SubmitTimeBefore": Union[datetime, str],
-        "SubmitTimeAfter": Union[datetime, str],
+        "JobName": NotRequired[str],
+        "JobStatus": NotRequired[JobStatusType],
+        "SubmitTimeBefore": NotRequired[Union[datetime, str]],
+        "SubmitTimeAfter": NotRequired[Union[datetime, str]],
     },
-    total=False,
 )
 
 ComprehendMedicalAsyncJobPropertiesTypeDef = TypedDict(
     "ComprehendMedicalAsyncJobPropertiesTypeDef",
     {
-        "JobId": str,
-        "JobName": str,
-        "JobStatus": JobStatusType,
-        "Message": str,
-        "SubmitTime": datetime,
-        "EndTime": datetime,
-        "ExpirationTime": datetime,
-        "InputDataConfig": "InputDataConfigTypeDef",
-        "OutputDataConfig": "OutputDataConfigTypeDef",
-        "LanguageCode": Literal["en"],
-        "DataAccessRoleArn": str,
-        "ManifestFilePath": str,
-        "KMSKey": str,
-        "ModelVersion": str,
+        "JobId": NotRequired[str],
+        "JobName": NotRequired[str],
+        "JobStatus": NotRequired[JobStatusType],
+        "Message": NotRequired[str],
+        "SubmitTime": NotRequired[datetime],
+        "EndTime": NotRequired[datetime],
+        "ExpirationTime": NotRequired[datetime],
+        "InputDataConfig": NotRequired["InputDataConfigTypeDef"],
+        "OutputDataConfig": NotRequired["OutputDataConfigTypeDef"],
+        "LanguageCode": NotRequired[Literal["en"]],
+        "DataAccessRoleArn": NotRequired[str],
+        "ManifestFilePath": NotRequired[str],
+        "KMSKey": NotRequired[str],
+        "ModelVersion": NotRequired[str],
     },
-    total=False,
 )
 
 DescribeEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
@@ -310,70 +308,65 @@ DetectPHIResponseTypeDef = TypedDict(
 EntityTypeDef = TypedDict(
     "EntityTypeDef",
     {
-        "Id": int,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Score": float,
-        "Text": str,
-        "Category": EntityTypeType,
-        "Type": EntitySubTypeType,
-        "Traits": List["TraitTypeDef"],
-        "Attributes": List["AttributeTypeDef"],
+        "Id": NotRequired[int],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Score": NotRequired[float],
+        "Text": NotRequired[str],
+        "Category": NotRequired[EntityTypeType],
+        "Type": NotRequired[EntitySubTypeType],
+        "Traits": NotRequired[List["TraitTypeDef"]],
+        "Attributes": NotRequired[List["AttributeTypeDef"]],
     },
-    total=False,
 )
 
 ICD10CMAttributeTypeDef = TypedDict(
     "ICD10CMAttributeTypeDef",
     {
-        "Type": ICD10CMAttributeTypeType,
-        "Score": float,
-        "RelationshipScore": float,
-        "Id": int,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Text": str,
-        "Traits": List["ICD10CMTraitTypeDef"],
-        "Category": ICD10CMEntityTypeType,
-        "RelationshipType": ICD10CMRelationshipTypeType,
+        "Type": NotRequired[ICD10CMAttributeTypeType],
+        "Score": NotRequired[float],
+        "RelationshipScore": NotRequired[float],
+        "Id": NotRequired[int],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Text": NotRequired[str],
+        "Traits": NotRequired[List["ICD10CMTraitTypeDef"]],
+        "Category": NotRequired[ICD10CMEntityTypeType],
+        "RelationshipType": NotRequired[ICD10CMRelationshipTypeType],
     },
-    total=False,
 )
 
 ICD10CMConceptTypeDef = TypedDict(
     "ICD10CMConceptTypeDef",
     {
-        "Description": str,
-        "Code": str,
-        "Score": float,
+        "Description": NotRequired[str],
+        "Code": NotRequired[str],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
 ICD10CMEntityTypeDef = TypedDict(
     "ICD10CMEntityTypeDef",
     {
-        "Id": int,
-        "Text": str,
-        "Category": Literal["MEDICAL_CONDITION"],
-        "Type": ICD10CMEntityTypeType,
-        "Score": float,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Attributes": List["ICD10CMAttributeTypeDef"],
-        "Traits": List["ICD10CMTraitTypeDef"],
-        "ICD10CMConcepts": List["ICD10CMConceptTypeDef"],
+        "Id": NotRequired[int],
+        "Text": NotRequired[str],
+        "Category": NotRequired[Literal["MEDICAL_CONDITION"]],
+        "Type": NotRequired[ICD10CMEntityTypeType],
+        "Score": NotRequired[float],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Attributes": NotRequired[List["ICD10CMAttributeTypeDef"]],
+        "Traits": NotRequired[List["ICD10CMTraitTypeDef"]],
+        "ICD10CMConcepts": NotRequired[List["ICD10CMConceptTypeDef"]],
     },
-    total=False,
 )
 
 ICD10CMTraitTypeDef = TypedDict(
     "ICD10CMTraitTypeDef",
     {
-        "Name": ICD10CMTraitNameType,
-        "Score": float,
+        "Name": NotRequired[ICD10CMTraitNameType],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
 InferICD10CMRequestRequestTypeDef = TypedDict(
@@ -429,33 +422,21 @@ InferSNOMEDCTResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredInputDataConfigTypeDef = TypedDict(
-    "_RequiredInputDataConfigTypeDef",
+InputDataConfigTypeDef = TypedDict(
+    "InputDataConfigTypeDef",
     {
         "S3Bucket": str,
+        "S3Key": NotRequired[str],
     },
 )
-_OptionalInputDataConfigTypeDef = TypedDict(
-    "_OptionalInputDataConfigTypeDef",
-    {
-        "S3Key": str,
-    },
-    total=False,
-)
-
-
-class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
-    pass
-
 
 ListEntitiesDetectionV2JobsRequestRequestTypeDef = TypedDict(
     "ListEntitiesDetectionV2JobsRequestRequestTypeDef",
     {
-        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
-        "NextToken": str,
-        "MaxResults": int,
+        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
@@ -472,11 +453,10 @@ ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
 ListICD10CMInferenceJobsRequestRequestTypeDef = TypedDict(
     "ListICD10CMInferenceJobsRequestRequestTypeDef",
     {
-        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
-        "NextToken": str,
-        "MaxResults": int,
+        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
@@ -493,11 +473,10 @@ ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
 ListPHIDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListPHIDetectionJobsRequestRequestTypeDef",
     {
-        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
-        "NextToken": str,
-        "MaxResults": int,
+        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListPHIDetectionJobsResponseTypeDef = TypedDict(
@@ -514,11 +493,10 @@ ListPHIDetectionJobsResponseTypeDef = TypedDict(
 ListRxNormInferenceJobsRequestRequestTypeDef = TypedDict(
     "ListRxNormInferenceJobsRequestRequestTypeDef",
     {
-        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
-        "NextToken": str,
-        "MaxResults": int,
+        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListRxNormInferenceJobsResponseTypeDef = TypedDict(
@@ -535,11 +513,10 @@ ListRxNormInferenceJobsResponseTypeDef = TypedDict(
 ListSNOMEDCTInferenceJobsRequestRequestTypeDef = TypedDict(
     "ListSNOMEDCTInferenceJobsRequestRequestTypeDef",
     {
-        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
-        "NextToken": str,
-        "MaxResults": int,
+        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListSNOMEDCTInferenceJobsResponseTypeDef = TypedDict(
@@ -553,24 +530,13 @@ ListSNOMEDCTInferenceJobsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredOutputDataConfigTypeDef = TypedDict(
-    "_RequiredOutputDataConfigTypeDef",
+OutputDataConfigTypeDef = TypedDict(
+    "OutputDataConfigTypeDef",
     {
         "S3Bucket": str,
+        "S3Key": NotRequired[str],
     },
 )
-_OptionalOutputDataConfigTypeDef = TypedDict(
-    "_OptionalOutputDataConfigTypeDef",
-    {
-        "S3Key": str,
-    },
-    total=False,
-)
-
-
-class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputDataConfigTypeDef):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -586,144 +552,121 @@ ResponseMetadataTypeDef = TypedDict(
 RxNormAttributeTypeDef = TypedDict(
     "RxNormAttributeTypeDef",
     {
-        "Type": RxNormAttributeTypeType,
-        "Score": float,
-        "RelationshipScore": float,
-        "Id": int,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Text": str,
-        "Traits": List["RxNormTraitTypeDef"],
+        "Type": NotRequired[RxNormAttributeTypeType],
+        "Score": NotRequired[float],
+        "RelationshipScore": NotRequired[float],
+        "Id": NotRequired[int],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Text": NotRequired[str],
+        "Traits": NotRequired[List["RxNormTraitTypeDef"]],
     },
-    total=False,
 )
 
 RxNormConceptTypeDef = TypedDict(
     "RxNormConceptTypeDef",
     {
-        "Description": str,
-        "Code": str,
-        "Score": float,
+        "Description": NotRequired[str],
+        "Code": NotRequired[str],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
 RxNormEntityTypeDef = TypedDict(
     "RxNormEntityTypeDef",
     {
-        "Id": int,
-        "Text": str,
-        "Category": Literal["MEDICATION"],
-        "Type": RxNormEntityTypeType,
-        "Score": float,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Attributes": List["RxNormAttributeTypeDef"],
-        "Traits": List["RxNormTraitTypeDef"],
-        "RxNormConcepts": List["RxNormConceptTypeDef"],
+        "Id": NotRequired[int],
+        "Text": NotRequired[str],
+        "Category": NotRequired[Literal["MEDICATION"]],
+        "Type": NotRequired[RxNormEntityTypeType],
+        "Score": NotRequired[float],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Attributes": NotRequired[List["RxNormAttributeTypeDef"]],
+        "Traits": NotRequired[List["RxNormTraitTypeDef"]],
+        "RxNormConcepts": NotRequired[List["RxNormConceptTypeDef"]],
     },
-    total=False,
 )
 
 RxNormTraitTypeDef = TypedDict(
     "RxNormTraitTypeDef",
     {
-        "Name": Literal["NEGATION"],
-        "Score": float,
+        "Name": NotRequired[Literal["NEGATION"]],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
 SNOMEDCTAttributeTypeDef = TypedDict(
     "SNOMEDCTAttributeTypeDef",
     {
-        "Category": SNOMEDCTEntityCategoryType,
-        "Type": SNOMEDCTAttributeTypeType,
-        "Score": float,
-        "RelationshipScore": float,
-        "RelationshipType": SNOMEDCTRelationshipTypeType,
-        "Id": int,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Text": str,
-        "Traits": List["SNOMEDCTTraitTypeDef"],
-        "SNOMEDCTConcepts": List["SNOMEDCTConceptTypeDef"],
+        "Category": NotRequired[SNOMEDCTEntityCategoryType],
+        "Type": NotRequired[SNOMEDCTAttributeTypeType],
+        "Score": NotRequired[float],
+        "RelationshipScore": NotRequired[float],
+        "RelationshipType": NotRequired[SNOMEDCTRelationshipTypeType],
+        "Id": NotRequired[int],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Text": NotRequired[str],
+        "Traits": NotRequired[List["SNOMEDCTTraitTypeDef"]],
+        "SNOMEDCTConcepts": NotRequired[List["SNOMEDCTConceptTypeDef"]],
     },
-    total=False,
 )
 
 SNOMEDCTConceptTypeDef = TypedDict(
     "SNOMEDCTConceptTypeDef",
     {
-        "Description": str,
-        "Code": str,
-        "Score": float,
+        "Description": NotRequired[str],
+        "Code": NotRequired[str],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
 SNOMEDCTDetailsTypeDef = TypedDict(
     "SNOMEDCTDetailsTypeDef",
     {
-        "Edition": str,
-        "Language": str,
-        "VersionDate": str,
+        "Edition": NotRequired[str],
+        "Language": NotRequired[str],
+        "VersionDate": NotRequired[str],
     },
-    total=False,
 )
 
 SNOMEDCTEntityTypeDef = TypedDict(
     "SNOMEDCTEntityTypeDef",
     {
-        "Id": int,
-        "Text": str,
-        "Category": SNOMEDCTEntityCategoryType,
-        "Type": SNOMEDCTEntityTypeType,
-        "Score": float,
-        "BeginOffset": int,
-        "EndOffset": int,
-        "Attributes": List["SNOMEDCTAttributeTypeDef"],
-        "Traits": List["SNOMEDCTTraitTypeDef"],
-        "SNOMEDCTConcepts": List["SNOMEDCTConceptTypeDef"],
+        "Id": NotRequired[int],
+        "Text": NotRequired[str],
+        "Category": NotRequired[SNOMEDCTEntityCategoryType],
+        "Type": NotRequired[SNOMEDCTEntityTypeType],
+        "Score": NotRequired[float],
+        "BeginOffset": NotRequired[int],
+        "EndOffset": NotRequired[int],
+        "Attributes": NotRequired[List["SNOMEDCTAttributeTypeDef"]],
+        "Traits": NotRequired[List["SNOMEDCTTraitTypeDef"]],
+        "SNOMEDCTConcepts": NotRequired[List["SNOMEDCTConceptTypeDef"]],
     },
-    total=False,
 )
 
 SNOMEDCTTraitTypeDef = TypedDict(
     "SNOMEDCTTraitTypeDef",
     {
-        "Name": SNOMEDCTTraitNameType,
-        "Score": float,
+        "Name": NotRequired[SNOMEDCTTraitNameType],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
-_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
-    "_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef",
+StartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "StartEntitiesDetectionV2JobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
+        "JobName": NotRequired[str],
+        "ClientRequestToken": NotRequired[str],
+        "KMSKey": NotRequired[str],
     },
 )
-_OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
-    "_OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef",
-    {
-        "JobName": str,
-        "ClientRequestToken": str,
-        "KMSKey": str,
-    },
-    total=False,
-)
-
-
-class StartEntitiesDetectionV2JobRequestRequestTypeDef(
-    _RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef,
-    _OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef,
-):
-    pass
-
 
 StartEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "StartEntitiesDetectionV2JobResponseTypeDef",
@@ -733,32 +676,18 @@ StartEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredStartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
-    "_RequiredStartICD10CMInferenceJobRequestRequestTypeDef",
+StartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "StartICD10CMInferenceJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
+        "JobName": NotRequired[str],
+        "ClientRequestToken": NotRequired[str],
+        "KMSKey": NotRequired[str],
     },
 )
-_OptionalStartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
-    "_OptionalStartICD10CMInferenceJobRequestRequestTypeDef",
-    {
-        "JobName": str,
-        "ClientRequestToken": str,
-        "KMSKey": str,
-    },
-    total=False,
-)
-
-
-class StartICD10CMInferenceJobRequestRequestTypeDef(
-    _RequiredStartICD10CMInferenceJobRequestRequestTypeDef,
-    _OptionalStartICD10CMInferenceJobRequestRequestTypeDef,
-):
-    pass
-
 
 StartICD10CMInferenceJobResponseTypeDef = TypedDict(
     "StartICD10CMInferenceJobResponseTypeDef",
@@ -768,32 +697,18 @@ StartICD10CMInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredStartPHIDetectionJobRequestRequestTypeDef = TypedDict(
-    "_RequiredStartPHIDetectionJobRequestRequestTypeDef",
+StartPHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "StartPHIDetectionJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
+        "JobName": NotRequired[str],
+        "ClientRequestToken": NotRequired[str],
+        "KMSKey": NotRequired[str],
     },
 )
-_OptionalStartPHIDetectionJobRequestRequestTypeDef = TypedDict(
-    "_OptionalStartPHIDetectionJobRequestRequestTypeDef",
-    {
-        "JobName": str,
-        "ClientRequestToken": str,
-        "KMSKey": str,
-    },
-    total=False,
-)
-
-
-class StartPHIDetectionJobRequestRequestTypeDef(
-    _RequiredStartPHIDetectionJobRequestRequestTypeDef,
-    _OptionalStartPHIDetectionJobRequestRequestTypeDef,
-):
-    pass
-
 
 StartPHIDetectionJobResponseTypeDef = TypedDict(
     "StartPHIDetectionJobResponseTypeDef",
@@ -803,32 +718,18 @@ StartPHIDetectionJobResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredStartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
-    "_RequiredStartRxNormInferenceJobRequestRequestTypeDef",
+StartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "StartRxNormInferenceJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
+        "JobName": NotRequired[str],
+        "ClientRequestToken": NotRequired[str],
+        "KMSKey": NotRequired[str],
     },
 )
-_OptionalStartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
-    "_OptionalStartRxNormInferenceJobRequestRequestTypeDef",
-    {
-        "JobName": str,
-        "ClientRequestToken": str,
-        "KMSKey": str,
-    },
-    total=False,
-)
-
-
-class StartRxNormInferenceJobRequestRequestTypeDef(
-    _RequiredStartRxNormInferenceJobRequestRequestTypeDef,
-    _OptionalStartRxNormInferenceJobRequestRequestTypeDef,
-):
-    pass
-
 
 StartRxNormInferenceJobResponseTypeDef = TypedDict(
     "StartRxNormInferenceJobResponseTypeDef",
@@ -838,32 +739,18 @@ StartRxNormInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
-    "_RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef",
+StartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "StartSNOMEDCTInferenceJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
+        "JobName": NotRequired[str],
+        "ClientRequestToken": NotRequired[str],
+        "KMSKey": NotRequired[str],
     },
 )
-_OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
-    "_OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef",
-    {
-        "JobName": str,
-        "ClientRequestToken": str,
-        "KMSKey": str,
-    },
-    total=False,
-)
-
-
-class StartSNOMEDCTInferenceJobRequestRequestTypeDef(
-    _RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef,
-    _OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef,
-):
-    pass
-
 
 StartSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
     "StartSNOMEDCTInferenceJobResponseTypeDef",
@@ -951,17 +838,15 @@ StopSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
 TraitTypeDef = TypedDict(
     "TraitTypeDef",
     {
-        "Name": AttributeNameType,
-        "Score": float,
+        "Name": NotRequired[AttributeNameType],
+        "Score": NotRequired[float],
     },
-    total=False,
 )
 
 UnmappedAttributeTypeDef = TypedDict(
     "UnmappedAttributeTypeDef",
     {
-        "Type": EntityTypeType,
-        "Attribute": "AttributeTypeDef",
+        "Type": NotRequired[EntityTypeType],
+        "Attribute": NotRequired["AttributeTypeDef"],
     },
-    total=False,
 )
